@@ -407,25 +407,11 @@ nautilus_canvas_view_get_directory_sort_by (NautilusCanvasView *canvas_view,
 static const SortCriterion *
 get_default_sort_order (NautilusFile *file)
 {
-    NautilusFileSortType sort_type, default_sort_order;
+    NautilusFileSortType sort_type;
     gboolean reversed;
 
-    default_sort_order = g_settings_get_enum (nautilus_preferences,
-                                              NAUTILUS_PREFERENCES_DEFAULT_SORT_ORDER);
-    reversed = g_settings_get_boolean (nautilus_preferences,
-                                       NAUTILUS_PREFERENCES_DEFAULT_SORT_IN_REVERSE_ORDER);
-
-    /* If this is a special folder (e.g. search or recent), override the sort
-     * order and reversed flag with values appropriate for the folder */
     sort_type = nautilus_file_get_default_sort_type (file, &reversed);
 
-    if (sort_type == NAUTILUS_FILE_SORT_NONE)
-    {
-        sort_type = CLAMP (default_sort_order,
-                           NAUTILUS_FILE_SORT_BY_DISPLAY_NAME,
-                           NAUTILUS_FILE_SORT_BY_ATIME);
-    }
-
     return get_sort_criterion_by_sort_type (sort_type, reversed);
 }
 
@@ -1434,6 +1420,18 @@ canvas_view_handle_uri_list (NautilusCanvasContainer *container,
                                               item_uris, target_uri, action);
 }
 
+/* Handles an URL received from Mozilla */
+static void
+canvas_view_handle_netscape_url (NautilusCanvasContainer *container,
+                                 const char              *encoded_url,
+                                 const char              *target_uri,
+                                 GdkDragAction            action,
+                                 NautilusCanvasView      *view)
+{
+    nautilus_files_view_handle_netscape_url_drop (NAUTILUS_FILES_VIEW (view),
+                                                  encoded_url, target_uri, action);
+}
+
 static void
 canvas_view_handle_text (NautilusCanvasContainer *container,
                          const char              *text,
@@ -1614,6 +1612,8 @@ nautilus_canvas_view_init (NautilusCanvasView *canvas_view)
 
     g_signal_connect_object (canvas_container, "handle-uri-list",
                              G_CALLBACK (canvas_view_handle_uri_list), canvas_view, 0);
+    g_signal_connect_object (canvas_container, "handle-netscape-url",
+                             G_CALLBACK (canvas_view_handle_netscape_url), canvas_view, 0);
     g_signal_connect_object (canvas_container, "handle-text",
                              G_CALLBACK (canvas_view_handle_text), canvas_view, 0);
     g_signal_connect_object (canvas_container, "handle-raw",
